@@ -20,9 +20,8 @@ import time
 import tyrs
 import signal                   # resize event
 import curses
+import logging
 from user import User
-from timeline import Timeline
-from message import FlashMessage
 from utils import html_unescape, encode, get_source, get_urls
 
 class Interface(object):
@@ -137,7 +136,7 @@ class Interface(object):
             self.change_buffer(self.buffers[new_index])
 
     def display_flash_message(self):
-        if self.api.flash_message.event:
+        if self.api.flash_message.event and not self.refresh_token:
             msg = self.api.flash_message.get_msg()
             level = self.api.flash_message.level
             msg_color = { 0: 'info_msg', 1: 'warning_msg', }
@@ -167,10 +166,11 @@ class Interface(object):
         '''Main entry to display a timeline, as it does not take arguments,
            make sure to set self.buffer before
         '''
-        self.set_max_window_size()
-        self.set_date()
         try:
             if not self.refresh_token:
+                self.set_max_window_size()
+                self.set_date()
+
                 timeline = self.select_current_timeline()
                 statuses_count = len(timeline.statuses)
 
@@ -196,13 +196,14 @@ class Interface(object):
                 self.screen.refresh()
                 self.check_current_not_on_screen()
         except curses.error:
+            logging.error('Curses error for display_timeline')
             pass
 
     def check_for_last_read(self, id):
         if self.buffer == 'home':
             if self.last_read_home == str(id):
-                self.screen.hline(self.current_y, 0, '-', self.maxyx[1]-1)
-                self.current_y += 2
+                self.screen.hline(self.current_y, 1, '-', self.maxyx[1]-3)
+                self.current_y += 1
 
     def set_date(self):
         self.date = time.strftime("%d %b", time.gmtime())
@@ -303,7 +304,11 @@ class Interface(object):
             if self.conf.params['old_skool_border']:
                 panel.border('|','|','-','-','+','+','+','+')
             else:
-                panel.border(0)
+                if self.conf.params['compact']:
+                    panel.border(curses.ACS_VLINE, curses.ACS_VLINE, curses.ACS_HLINE, ' ',
+                                 curses.ACS_ULCORNER, curses.ACS_URCORNER, ' ', ' ')
+                else:
+                    panel.border(0)
 
         # Highlight the current status
         if timeline.current == i:
@@ -318,7 +323,7 @@ class Interface(object):
         except curses.error:
             pass
         # An adjustment to compress a little the display
-        if self.conf.params['compress']:
+        if self.conf.params['compact']:
             c = -1
         else:
             c = 0
@@ -428,38 +433,56 @@ class Interface(object):
         return result
 
     def get_header(self, status):
+        retweeted = ''
+        reply = ''
+        retweet_count = ''
+        retweeter = ''
+        source = self.get_source(status)
         nick = self.get_nick(status)
         time = self.get_time(status)
 
-        if status.rt and self.conf.params['retweet_by'] == 1:
-            origin = self.origin_of_retweet(status)
-            header = ' %s - %s ' % (time, origin) + u"\u267b" + ' %s ' % nick
-        else:
-            header = " %s - %s " % (time, nick)
-
         if self.is_reply(status):
-            header += u'\u2709 '
+            reply = u' \u2709'
+        if status.rt:
+            retweeted = u" \u267b "
+            retweeter = nick
+            nick = self.origin_of_retweet(status)
 
-        source = self.get_source(status)
-        if self.conf.params['source'] and source:
-            header += ' (%s)' % source
+        if self.get_retweet_count(status):
+            retweet_count = str(self.get_retweet_count(status))
+
+        header_template = self.conf.params['header_template'] 
+        header = unicode(header_template).format(
+            time = time,
+            nick = nick,
+            reply = reply,
+            retweeted = retweeted,
+            source = source,
+            retweet_count = retweet_count,
+            retweeter = retweeter
+            )
 
         return encode(header)
 
     def get_source(self, status):
+        source = ''
         if hasattr(status, 'source'):
             source = get_source(status.source)
-        else:
-            source = ''
+
         return source
 
     def get_nick(self, status):
         if hasattr(status, 'user'):
             nick = status.user.screen_name
         else:
+            #Used for direct messages
             nick = status.sender_screen_name
 
-        return encode(nick)
+        return nick
+
+    def get_retweet_count(self, status):
+        if hasattr(status, 'retweet_count'):
+            return status.retweet_count
 
     def is_retweet(self, status):
         status.rt = self.regex_retweet.match(status.text)
