@@ -14,6 +14,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import tyrs
+import logging
 import threading
 from urllib2 import URLError
 
@@ -29,6 +30,7 @@ class UpdateThread(threading.Thread):
         self._stopevent = threading.Event()
 
     def run(self):
+        logging.info('Thread started')
         while not self._stopevent.isSet():
             self._stopevent.wait(self.conf.params['refresh'] * 60.0)
             if not self._stopevent.isSet():
@@ -36,10 +38,13 @@ class UpdateThread(threading.Thread):
                     self.api.update_timeline('home')
                     self.api.update_timeline('mentions')
                     self.api.update_timeline('direct')
-
-                except URLError:
-                    pass
-                self.interface.display_timeline()
+                    self.interface.display_timeline()
+                except URLError, e:
+                    logging.error('Thread issue with URLError {0}'.format(e))
+                    logging.info('Tread stoped')
+                    self.stop()
+                    update = UpdateThread()
+                    update.start()
 
     def stop(self):
         self._stopevent.set()
